FrameBufferOperations

Trait FrameBufferOperations 

pub trait FrameBufferOperations: FrameBuffer {
    // Required methods
    fn erase(&mut self);
    fn set_pixel(&mut self, p: Point, color: Color);
}
Trait for all operations a user may want to call on a framebuffer.

Required Methods

fn erase(&mut self)

Erase pixel colors while preserving control bits. This is much faster than format() and is the typical way to clear the display.

fn set_pixel(&mut self, p: Point, color: Color)

Set a pixel in the framebuffer.

Implementors

Source

impl<F: FrameBufferOperations + FrameBuffer, M: PixelRemapper, const PANEL_ROWS: usize, const PANEL_COLS: usize, const NROWS: usize, const BITS: u8, const FRAME_COUNT: usize, const TILE_ROWS: usize, const TILE_COLS: usize, const FB_COLS: usize> FrameBufferOperations for TiledFrameBuffer<F, M, PANEL_ROWS, PANEL_COLS, NROWS, BITS, FRAME_COUNT, TILE_ROWS, TILE_COLS, FB_COLS>

Source

impl<const NROWS: usize, const COLS: usize, const PLANES: usize> FrameBufferOperations for hub75_framebuffer::bitplane::latched::DmaFrameBuffer<NROWS, COLS, PLANES>

Source

impl<const NROWS: usize, const COLS: usize, const PLANES: usize> FrameBufferOperations for hub75_framebuffer::bitplane::plain::DmaFrameBuffer<NROWS, COLS, PLANES>

Source

impl<const ROWS: usize, const COLS: usize, const NROWS: usize, const BITS: u8, const FRAME_COUNT: usize> FrameBufferOperations for hub75_framebuffer::latched::DmaFrameBuffer<ROWS, COLS, NROWS, BITS, FRAME_COUNT>

Source

impl<const ROWS: usize, const COLS: usize, const NROWS: usize, const BITS: u8, const FRAME_COUNT: usize> FrameBufferOperations for hub75_framebuffer::plain::DmaFrameBuffer<ROWS, COLS, NROWS, BITS, FRAME_COUNT>