pub trait FrameBufferOperations: FrameBuffer {
// Required methods
fn erase(&mut self);
fn set_pixel(&mut self, p: Point, color: Color);
}Expand description
Trait for all operations a user may want to call on a framebuffer.
pub trait FrameBufferOperations: FrameBuffer {
// Required methods
fn erase(&mut self);
fn set_pixel(&mut self, p: Point, color: Color);
}Trait for all operations a user may want to call on a framebuffer.